==> nextcloud-21.0.4.tgz: nextcloud/apps/privacy/l10n/it.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Riservatezza",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Il centro della riservatezza ti mostra dove sono archiviati i tuoi dati e chi può accedervi, perché li hai condivisi con loro o perché sono amministratori.",
    "Remove external admin" : "Rimuovi amministratore esterno",
    "Add external admin" : "Aggiungi amministratore esterno",
    "Name of external admin" : "Nome dell'amministratore esterno",
    "This server is using full-disk-encryption." : "Questo server utilizzar la cifratura completa del disco.",
    "This server is protected with full-disk-encryption." : "Questo server è protetto con la cifratura completa del disco.",
    "Your files are not protected by encryption." : "I tuoi file non sono protetti con la cifratura.",
    "Your data is located in:" : "I tuoi dati si trovano in:",
    "The admin hasn't selected the location of the server yet." : "L'amministratore non ha ancora selezionato la posizione del server.",
    "Change data location" : "Cambia posizione dei dati",
    "Please select a region" : "Seleziona una regione",
    "You don't have any shares with individual users." : "Non hai alcuna condivisione con singoli utenti.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirati Arabi Uniti",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartide",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Isole Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia ed Erzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgio",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthelemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius e Saba",
    "Brazil" : "Brasile",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Isola Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorussia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Isole Cocos (Keeling)",
    "Democratic Republic of the Congo" : "Repubblica Democratica del Congo",
    "Central African Republic" : "Repubblica Centrafricana",
    "Congo" : "Congo",
    "Switzerland" : "Svizzera",
    "Cote d'Ivoire" : "Costa d'Avorio",
    "Cook Islands" : "Isole di Cook",
    "Chile" : "Cile",
    "Cameroon" : "Camerun",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Capo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Isola di Natale",
    "Cyprus" : "Cipro",
    "Czech" : "Repubblica Ceca",
    "Germany" : "Germania",
    "Djibouti" : "Gibuti",
    "Denmark" : "Danimarca",
    "Dominican Republic" : "Repubblica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egitto",
    "West Sahara" : "Sahara occidentale",
    "Eritrea" : "Eritrea",
    "Spain" : "Spagna",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Figi",
    "Falkland Islands" : "Isole Falkland",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Isole Faroe",
    "France" : "Francia",
    "Gabon" : "Gabon",
    "United Kingdom" : "Regno Unito",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana Francese",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibilterra",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupa",
    "Equatorial Guinea" : "Guinea Equatoriale",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e Isole Sandwich Australi",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Isole Heard e McDonald",
    "Croatia" : "Croazia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungheria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israele",
    "Isle of Man" : "Isola di Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Britannico dell'Oceano Indiani",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islanda",
    "Italy" : "Italia",
    "Jamaica" : "Giamaica",
    "Jordan" : "Giordania",
    "Japan" : "Giappone",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizistan",
    "Cambodia" : "Cambogia",
    "Kiribati" : "Kiribati",
    "Comores" : "Comore",
    "Saint Kitts and Nevis" : "Saint Kitts e Nevis",
    "North Korea" : "Corea del Nord",
    "South Korea" : "Corea del Sud",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Isole Cayman",
    "Kazakhstan" : "Kazakistan",
    "Laos" : "Laos",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Lussemburgo",
    "Latvia" : "Lettonia",
    "Libya" : "Libia",
    "Morocco" : "Marocco",
    "Monaco" : "Monaco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Isole Marshall",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Isole Marianne settentrionali",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldive",
    "Malawi" : "Malawi",
    "Mexico" : "Messico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambico",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nuova Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Isola Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Paesi Bassi",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nuova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Perù",
    "French Polynesia" : "Polinesia Francese",
    "Papua New Guinea" : "Papua Nuova Guinea",
    "Philippines" : "Filippine",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Saint Pierre e Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portogallo",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Isole Salomone",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Svezia",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sant'Elena, Ascensione e Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard e Jan Mayen",
    "Slovakia" : "Slovacchia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan del Sud",
    "Sao Tome and Principe" : "Sao Tome e Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Siria",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Isole Turks e Caicos",
    "Chad" : "Ciad",
    "Fr. S. Antarctic Lands" : "Terre australi e antartiche francesi",
    "Togo" : "Togo",
    "Thailand" : "Thailandia",
    "Tajikistan" : "Tagikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Est",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turchia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Isole minori esterne degli Stati Uniti d'America",
    "United States" : "Stati Uniti d'America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Città del Vaticano",
    "Saint Vincent and the Grenadines" : "Saint Vincent e Grenadine",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Isole Vergini (Britanniche)",
    "Virgin Islands (U.S.)" : "Isole Vergini (U.S.A.)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Il tuo account Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "I tuoi dati rappresentano chi sei e possono essere facilmente abusati. Noi di Nextcloud riteniamo che tu abbia il diritto di decidere cosa succede ai tuoi dati. Nextcloud protegge i tuoi diritti come definito nel Manifesto dei dati utente!",
    "User Data Manifesto 2.0" : "Manifesto dei dati utente 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definizione dei i diritti fondamentali delle persone per controllare i propri dati nell'era di Internet",
    "Control" : "Controllo",
    "over user data access" : "sull'accesso ai dati utente",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "I dati caricati esplicitamente e volontariamente da un utente devono essere sotto il controllo totale dell'utente. Gli utenti dovrebbero poter decidere a chi concedere l'accesso diretto ai propri dati e con quali permessi e licenze tale accesso dovrebbe essere concesso.",
    "Knowledge" : "Conoscenza",
    "of how the data is stored" : "di come i dati vengono archiviati",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando i dati vengono inviati a uno specifico fornitore di servizi, gli utenti dovrebbero essere informati su dove lo specifico fornitore di servizi memorizza i dati, per quanto tempo, in quale giurisdizione opera lo specifico fornitore di servizi e quali leggi sono applicabili.",
    "Freedom" : "Libertà",
    "to choose a platform" : "di scegliere una piattaforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Gli utenti dovrebbero sempre poter estrarre i propri dati dal servizio in qualsiasi momento senza che si verifichi un blocco da parte del fornitore. Per garantire ciò sono necessari standard aperti per formati e protocolli.",
    "Learn more ↗" : "Ulteriori informazioni ↗",
    "Where is your data?" : "Dove sono i tuoi dati?",
    "Who has access to your data?" : "Chi ha accesso ai tuoi dati?",
    "Administrators" : "Amministratori",
    "People you shared with" : "Persone con cui hai condiviso",
    "Privacy policy" : "Criterio di riservatezza",
    "Read the privacy policy." : "Leggi subito i criteri di riservatezza.",
    "Encryption" : "Cifratura",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}. In aggiunta, questo server è protetto con la cifratura completa del disco.",
    "Your data is located in: " : "I tuoi dati si trovano in: "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8.tgz: nextcloud/apps/privacy/l10n/it.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Riservatezza",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Il centro della riservatezza ti mostra dove sono archiviati i tuoi dati e chi può accedervi, perché li hai condivisi con loro o perché sono amministratori.",
    "Remove external admin" : "Rimuovi amministratore esterno",
    "Add external admin" : "Aggiungi amministratore esterno",
    "Name of external admin" : "Nome dell'amministratore esterno",
    "This server is using full-disk-encryption." : "Questo server utilizzar la cifratura completa del disco.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "La tua archiviazione è cifrata usando una {linkopen}crittografia lato server ↗{linkclose} con una chiave primaria.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "I tuoi file su archiviazioni esterne possono essere cifrati usando una {linkopen}crittografia lato server ↗{linkclose} con una chiave primaria in base alla loro configurazione.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "La tua archiviazione è cifrata usando una {linkopen}crittografia lato server ↗{linkclose} con una chiave utente individuale.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "I tuoi file su archiviazioni esterne possono essere cifrati usando una {linkopen}crittografia lato server ↗{linkclose} con una chiave utente individuale in base alla loro configurazione.",
    "Additionally, this server is protected with full-disk-encryption." : "Inoltre, questo server è protetto da una crittografia del disco completa.",
    "This server is protected with full-disk-encryption." : "Questo server è protetto con la cifratura completa del disco.",
    "Your files are not protected by encryption." : "I tuoi file non sono protetti con la cifratura.",
    "Your data is located in:" : "I tuoi dati si trovano in:",
    "The admin has not selected the location of the server yet." : "L'amministratore non ha ancora selezionato la posizione del server.",
    "Change data location" : "Cambia posizione dei dati",
    "Please select a region" : "Seleziona una regione",
    "You don't have any shares with individual users." : "Non hai alcuna condivisione con singoli utenti.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirati Arabi Uniti",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartide",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Isole Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia ed Erzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgio",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthelemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius e Saba",
    "Brazil" : "Brasile",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Isola Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorussia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Isole Cocos (Keeling)",
    "Democratic Republic of the Congo" : "Repubblica Democratica del Congo",
    "Central African Republic" : "Repubblica Centrafricana",
    "Congo" : "Congo",
    "Switzerland" : "Svizzera",
    "Cote d'Ivoire" : "Costa d'Avorio",
    "Cook Islands" : "Isole di Cook",
    "Chile" : "Cile",
    "Cameroon" : "Camerun",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Capo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Isola di Natale",
    "Cyprus" : "Cipro",
    "Czech" : "Repubblica Ceca",
    "Germany" : "Germania",
    "Djibouti" : "Gibuti",
    "Denmark" : "Danimarca",
    "Dominican Republic" : "Repubblica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egitto",
    "West Sahara" : "Sahara occidentale",
    "Eritrea" : "Eritrea",
    "Spain" : "Spagna",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Figi",
    "Falkland Islands" : "Isole Falkland",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Isole Faroe",
    "France" : "Francia",
    "Gabon" : "Gabon",
    "United Kingdom" : "Regno Unito",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana Francese",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibilterra",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupa",
    "Equatorial Guinea" : "Guinea Equatoriale",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e Isole Sandwich Australi",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Isole Heard e McDonald",
    "Croatia" : "Croazia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungheria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israele",
    "Isle of Man" : "Isola di Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Britannico dell'Oceano Indiani",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islanda",
    "Italy" : "Italia",
    "Jamaica" : "Giamaica",
    "Jordan" : "Giordania",
    "Japan" : "Giappone",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizistan",
    "Cambodia" : "Cambogia",
    "Kiribati" : "Kiribati",
    "Comores" : "Comore",
    "Saint Kitts and Nevis" : "Saint Kitts e Nevis",
    "North Korea" : "Corea del Nord",
    "South Korea" : "Corea del Sud",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Isole Cayman",
    "Kazakhstan" : "Kazakistan",
    "Laos" : "Laos",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Lussemburgo",
    "Latvia" : "Lettonia",
    "Libya" : "Libia",
    "Morocco" : "Marocco",
    "Monaco" : "Monaco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Isole Marshall",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Isole Marianne settentrionali",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldive",
    "Malawi" : "Malawi",
    "Mexico" : "Messico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambico",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nuova Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Isola Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Paesi Bassi",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nuova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Perù",
    "French Polynesia" : "Polinesia Francese",
    "Papua New Guinea" : "Papua Nuova Guinea",
    "Philippines" : "Filippine",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Saint Pierre e Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portogallo",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Isole Salomone",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Svezia",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sant'Elena, Ascensione e Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard e Jan Mayen",
    "Slovakia" : "Slovacchia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan del Sud",
    "Sao Tome and Principe" : "Sao Tome e Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Siria",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Isole Turks e Caicos",
    "Chad" : "Ciad",
    "Fr. S. Antarctic Lands" : "Terre australi e antartiche francesi",
    "Togo" : "Togo",
    "Thailand" : "Thailandia",
    "Tajikistan" : "Tagikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Est",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turchia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Isole minori esterne degli Stati Uniti d'America",
    "United States" : "Stati Uniti d'America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Città del Vaticano",
    "Saint Vincent and the Grenadines" : "Saint Vincent e Grenadine",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Isole Vergini (Britanniche)",
    "Virgin Islands (U.S.)" : "Isole Vergini (U.S.A.)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "I tuoi dati rappresentano chi sei e possono essere facilmente abusati. Noi di Nextcloud riteniamo che tu abbia il diritto di decidere cosa succede ai tuoi dati. Nextcloud protegge i tuoi diritti come definito nel Manifesto dei dati utente!",
    "User Data Manifesto 2.0" : "Manifesto dei dati utente 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definizione dei i diritti fondamentali delle persone per controllare i propri dati nell'era di Internet",
    "Control" : "Controllo",
    "over user data access" : "sull'accesso ai dati utente",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "I dati caricati esplicitamente e volontariamente da un utente devono essere sotto il controllo totale dell'utente. Gli utenti dovrebbero poter decidere a chi concedere l'accesso diretto ai propri dati e con quali permessi e licenze tale accesso dovrebbe essere concesso.",
    "Knowledge" : "Conoscenza",
    "of how the data is stored" : "di come i dati vengono archiviati",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Quando i dati vengono inviati a uno specifico fornitore di servizi, gli utenti dovrebbero essere informati su dove lo specifico fornitore di servizi memorizza i dati, per quanto tempo, in quale giurisdizione opera lo specifico fornitore di servizi e quali leggi sono applicabili.",
    "Freedom" : "Libertà",
    "to choose a platform" : "di scegliere una piattaforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Gli utenti dovrebbero sempre poter estrarre i propri dati dal servizio in qualsiasi momento senza che si verifichi un blocco da parte del fornitore. Per garantire ciò sono necessari standard aperti per formati e protocolli.",
    "Learn more ↗" : "Ulteriori informazioni ↗",
    "Where is your data?" : "Dove sono i tuoi dati?",
    "Who has access to your data?" : "Chi ha accesso ai tuoi dati?",
    "Administrators" : "Amministratori",
    "People you shared with" : "Persone con cui hai condiviso",
    "Privacy policy" : "Criterio di riservatezza",
    "Read the privacy policy." : "Leggi subito i criteri di riservatezza.",
    "Encryption" : "Cifratura",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "I tuoi file sono cifrati con la. {linkopen}cifratura lato server ↗{linkclose}. In aggiunta, questo server è protetto con la cifratura completa del disco.",
    "Your data is located in: " : "I tuoi dati si trovano in: ",
    "The admin hasn't selected the location of the server yet." : "L'amministratore non ha ancora selezionato la posizione del server."
},
"nplurals=2; plural=(n != 1);");
